@@ -1,4 +1,4 @@
 from .sybil import Sybil
 from .document import Document
-from .region import Region
+from .region import Region, LexedRegion, Lexeme
 from .example import Example
